@@ -6,14 +6,6 @@ module Librarian
   module Mock
     class Environment < Environment
 
-      def adapter_name
-        "mock"
-      end
-
-      def adapter_version
-        VERSION
-      end
-
       def install_path
         nil
       end
